# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/media_transcription/media_transcription/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "MediaTranscription\\MediaTranscription\\": "packages/media_transcription/media_transcription/src",
            "MediaTranscription\\MediaTranscription\\Seeders\\": "packages/media_transcription/media_transcription/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        MediaTranscription\MediaTranscription\Providers\MediaTranscriptionServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'MediaTranscription'  => MediaTranscription\MediaTranscription\Facades\MediaTranscription::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=MediaTranscription\\MediaTranscription\\Seeders\\MediaTranscriptionTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="MediaTranscription\MediaTranscription\Providers\MediaTranscriptionServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="MediaTranscription\MediaTranscription\Providers\MediaTranscriptionServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="MediaTranscription\MediaTranscription\Providers\MediaTranscriptionServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/media_transcription/{modulename}

**User**

    http://path-to-route-folder/user/media_transcription/{modulename}

**Public**

    http://path-to-route-folder/media_transcriptions


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/media_transcription/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/media_transcription/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/media_transcription/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/media_transcription/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/media_transcription/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/media_transcription/{modulename}/{slug}
    METHOD: GET